OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migratzen ari da. Itxaron migrazioa osatu arte.",
    "Migration started …" : "Migration started …",
    "Saved" : "Gordeta",
    "Not saved" : "Ez da gorde",
    "Sending…" : "Bidaltzen...",
    "Email sent" : "Eposta bidalia",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
    "Valid until {date}" : "{date} arte baliogarria",
    "Delete" : "Ezabatu",
    "Local" : "Local",
    "Private" : "Pribatua",
    "Only visible to local users" : "Soilik bertako erabiltzaileentzako ikusgai",
    "Only visible to you" : "Zuretzat bakarrik ikusgai",
    "Contacts" : "Kontaktuak",
    "Visible to local users and to trusted servers" : "Bertako erabiltzaile eta zerbitzarien jendearentzat ikusgai",
    "Public" : "Publikoa",
    "Will be synced to a global and public address book" : "Helbide liburu global eta publikoan sinkronizatuko da",
    "Verify" : "Egiaztatu",
    "Verifying …" : "Egiaztatzen...",
    "Unable to change password" : "Ezin izan da pasahitza aldatu",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Select a profile picture" : "Profilaren irudia aukeratu",
    "Groups" : "Taldeak",
    "{actor} changed your password" : "{actor}-(e)k zure pasahitza aldatu du",
    "You changed your password" : "Zuk zure pasahitza aldatu duzu",
    "Your password was reset by an administrator" : "Administratzaile batek zure pasahitza berrezarri du",
    "{actor} changed your email address" : "{actor}-(e)k zure e-posta helbidea aldatu du",
    "You changed your email address" : "Zuk zure e-posta helbidea aldatu duzu",
    "Your email address was changed by an administrator" : "Administratzaile batek zure e-posta helbidea berrezarri du",
    "Security" : "Segurtasuna",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ongi hasi duzu saioa bi urratseko egiaztapenaren bidez (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Bi urratseko egiaztapenaren bidezko saioa hasteko ahaleginak huts egin du (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Zure pasahitza edo e-posta helbidea aldatu da",
    "Couldn't remove app." : "Ezin izan da aplikazioa kendu.",
    "Couldn't update app." : "Ezin izan da aplikazioa eguneratu.",
    "Wrong password" : "Pasahitz okerra",
    "No user supplied" : "Ez da erabiltzailerik zehaztu",
    "Authentication error" : "Autentifikazio errorea",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Eman berreskuratzeko administrazio  pasahitza, bestela erabiltzaile datu guztiak galduko dira",
    "Wrong admin recovery password. Please check the password and try again." : "Administratzailearen berreskuratze pasahitza ez egokia. Mesedez egiaztatu pasahitza eta saiatu berriz.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Motorrak ez du onartzen pasahitza aldatzea, baina erabiltzailearen zifratze-gakoa eguneratu da.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Aplikazioak aplikazio-biltegiaren edo federatutako hodei partekatzearen bidez instalatzen edo eguneratzen",
    "Federated Cloud Sharing" : "Federatutako hodei partekatzea",
    "Invalid SMTP password." : "SMTP pasahitza baliogabea",
    "Email setting test" : "E-postaren ezarpenen proba",
    "Well done, %s!" : "Ongi egina, %s!",
    "If you received this email, the email configuration seems to be correct." : "E-posta mezu hau jaso baduzu, e-postaren ezarpenak egokiak direnaren seinale.",
    "Email could not be sent. Check your mail server log" : "E-posta mezua ezin izan da bidali. Begiratu zure posta-zerbitzariaren egunkaria",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Arazo bat sortu da posta bidaltzerakoan. Berrikusi zure ezarpenak. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Epostaren erabiltzailea zehaztu behar duzu probako eposta bidali aurretik.",
    "Invalid mail address" : "Posta helbide baliogabea",
    "Settings saved" : "Ezarpenak gordeta",
    "Unable to change full name" : "Ezin izan da izena aldatu",
    "Unable to change email address" : "Ezin da helbide elektronikoa aldatu",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Zure Twitter kontua egiaztatzearren, bidali hurrengo txioa Twitter-era (egiaztatu zure mezuak ez duela lerro-jauzirik):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Zure webgunea egiaztatzearren, gorde hurrengo edukia zure webgunearen sustraiko  '.well-known/CloudIdVerificationCode.txt' (egiaztatu testu osoa lerro bakarrean dagoela):",
    "%1$s changed your password on %2$s." : "%1$s-(e)k zure pasahitza aldatu du %2$s-(e)n",
    "Your password on %s was changed." : "Zure %s-(e)ko pasahitza aldatu da.",
    "Your password on %s was reset by an administrator." : "Administratzaile batek zure %s-(e)ko pasahitza berrezarri du",
    "Password for %1$s changed on %2$s" : "%1$s-(r)en %2$s-(e)ko pasahitza aldatu da",
    "Password changed for %s" : "%s-(r)en pasahitza aldatu da",
    "If you did not request this, please contact an administrator." : "Zuk ez baduzu hau eskatu, jarri kontaktuan administratzailearekin.",
    "Your email address on %s was changed." : "Zure %s-(e)ko e-posta helbidea aldatu da.",
    "Your email address on %s was changed by an administrator." : "Administratzaile batek zure %s-(e)ko e-posta helbidea berrezarri du",
    "Email address for %1$s changed on %2$s" : "%1$s-(r)en %2$s-(e)ko e-posta helbidea aldatu da",
    "Email address changed for %s" : "%s-(r)en e-posta helbidea aldatu da",
    "The new email address is %s" : "E-posta helbide berria hau da: %s",
    "Your %s account was created" : "Zure %s kontua sortu da",
    "Welcome aboard" : "Ongi etorri barrura",
    "Welcome aboard %s" : "Ongi etorri barrura, %s",
    "Your username is: %s" : "Zure erabiltzailea hau da: %s",
    "Set your password" : "Ezarri zure pasahitza",
    "Go to %s" : "%s-ra joan",
    "Install Client" : "Instalatu bezeroa",
    "Unlimited" : "Mugarik gabe",
    "Limit to groups" : "Taldeetara mugatu",
    "Excluded groups" : "Baztertu taldeak",
    "Save changes" : "Gorde aldaketak",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikazio ofizialak komunitateak eta komunitatean garatzen dira. Funtzionalak dira eta produkziorako gertu daude.",
    "Official" : "Ofiziala",
    "Remove" : "Ezabatu",
    "Disable" : "Ez-gaitu",
    "All" : "Denak",
    "No results" : "Emaitzarik ez",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikazioa ezin da instalatu hurrengo menpekotasunak betetzen ez direlako:",
    "View in store" : "Dendan ikusi",
    "Visit website" : "Web orria ikusi",
    "Report a bug" : "Eman akats baten berri ",
    "User documentation" : "Erabiltzailearen dokumentazioa",
    "Admin documentation" : "Administratzailearen dokumentazioa",
    "Developer documentation" : "Garatzailearen dokumentazioa",
    "No apps found for your version" : "Ez dira aplikaziorik aurkitu zure bertsiorako",
    "Disable all" : "Desgaitu guztia",
    "Enable all" : "Gaitu denak",
    "Download and enable" : "Deskargatu eta gaitu",
    "Enable" : "Gaitu",
    "Enable untested app" : "Gaitu probatu gabeko aplikazioa",
    "The app will be downloaded from the app store" : "Aplikazioa aplikazio dendatik deskargatuko da",
    "Device settings" : "Gailuaren ezarpenak",
    "Allow filesystem access" : "Onartu fitxategi sisteman sarbidea",
    "Rename" : "Berrizendatu",
    "Revoke" : "Ezeztatu",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome Android-erako",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloud iOS aplikazioa",
    "Nextcloud Android app" : "Nextcloud Android aplikazioa",
    "Nextcloud Talk for iOS" : "Nextcloud Talk iOSentzat",
    "Nextcloud Talk for Android" : "Nextcloud Talk Androidentzat",
    "Sync client - {os}" : "Sinkronizatu bezeroaren - {os}",
    "This session" : "Saio hau",
    "Device" : "Gailu",
    "Last activity" : "Azken jarduera",
    "Devices & sessions" : "Gailuak eta saioak",
    "Web, desktop and mobile clients currently logged in to your account." : "Web-gune, mahaigain eta mugikorrean zure kontuan saioa hasita dago.",
    "Error while creating device token" : "Errorea gailuaren tokena sortzean",
    "Error while deleting the token" : "Errorea tokena ezabatzean",
    "App name" : "Aplikazioaren izena",
    "Create new app password" : "Sortu app pasahitza berria",
    "Use the credentials below to configure your app or device." : "Erabili kredentzialak beheko zure aplikazioa edo gailua konfiguratzeko.",
    "For security reasons this password will only be shown once." : "Segurtasun arrazoiengatik, pasahitz hau behin soilik erakutsiko da.",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Done" : "Egina",
    "Show QR code for mobile apps" : "Erakutsi QR kodea mugikorrentzako aplikazioetan",
    "Copied!" : "Kopiatua!",
    "Copy" : "Kopiatu",
    "New password" : "Pasahitz berria",
    "Add user in group" : "Gehitu erabiltzailea talde batean",
    "No language set" : "Ez da hizkuntzarik ezarri",
    "Never" : "Inoiz ez",
    "Delete user" : "Ezabatu erabiltzailea",
    "Disable user" : "Desgaitu erabiltzailea",
    "Enable user" : "Gaitu erabiltzailea",
    "Resend welcome email" : "Birbidali ongi etorri mezua",
    "{size} used" : "{size} erabilita",
    "Welcome mail sent!" : "Ongi etorri mezua bidalita!",
    "Display name" : "Erakutsi izena",
    "Email" : "E-posta",
    "Group admin for" : "Talde honen administratzailea",
    "Quota" : "Kuota",
    "Language" : "Hizkuntza",
    "Storage location" : "Biltegiratze kokapena",
    "User backend" : "Erabiltzaile jatorria",
    "Last login" : "Azken saioa",
    "Default language" : "Hizkuntza lehenetsia",
    "Add a new user" : "Gehitu erabiltze berria",
    "Default quota" : "Kuota lehenetsia",
    "All languages" : "Hizkuntza guztiak",
    "Your apps" : "Zure aplikazioak",
    "Disabled apps" : "Gaitu gabeko aplikazioak",
    "Updates" : "Eguneraketak",
    "App bundles" : "Aplikazio sortak",
    "New user" : "Erabiltzaile berria",
    "Default quota:" : "Lehenetsitako kuota:",
    "Show Languages" : "Erakutsi Hizkuntzak",
    "Show last login" : "Azken izen ematea erakutsi",
    "Show user backend" : "Bistaratu erabiltzaile motorra",
    "Remove group" : "Ezabatu taldea",
    "Admins" : "Administratzaileak",
    "Everyone" : "Edonor",
    "Add group" : "Taldea gehitu",
    "App update" : "Aplikazioaren eguneraketa",
    "Error: This app can not be enabled because it makes the server unstable" : "Errorea: aplikazioa hau ezin da gaitu zerbitzaria ezegonkor izatea egiten duelako",
    "SSL Root Certificates" : "SSL Root Certificates",
    "Common Name" : "Izen arrunta",
    "Valid until" : "Data hau arte baliogarria",
    "Issued By" : "Honek bidalita",
    "Valid until %s" : "%s arte baliogarria",
    "Import root certificate" : "Inportatu root ziurtagiria",
    "Administrator documentation" : "Administratzaile dokumentazioa",
    "Documentation" : "Dokumentazioa",
    "Forum" : "Foroa",
    "None" : "Ezer",
    "Login" : "Saio hasiera",
    "Plain" : "Arrunta",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-posta zerbitzaria",
    "Open documentation" : "Ireki dokumentazioa",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Zerbitzaria epostak bidaltzeko gai izatea garrantzitsua da, pasahitzak berrezartzeko eta abisuentzako",
    "Send mode" : "Bidaltzeko modua",
    "Encryption" : "Enkriptazioa",
    "From address" : "Helbidetik",
    "mail" : "posta",
    "Authentication method" : "Autentifikazio metodoa",
    "Authentication required" : "Autentikazioa beharrezkoa",
    "Server address" : "Zerbitzariaren helbidea",
    "Port" : "Portua",
    "Credentials" : "Kredentzialak",
    "SMTP Username" : "SMTP erabiltzaile-izena",
    "SMTP Password" : "SMTP pasahitza",
    "Test email settings" : "Probatu eposta ezarpenak",
    "Send email" : "Bidali eposta",
    "Security & setup warnings" : "Segurtasun eta konfigurazio abisuak",
    "All checks passed." : "Egiaztapen guztiak gaindituta.",
    "Version" : "Bertsioa",
    "Server-side encryption" : "Zerbitzariaren aldeko enkriptaketa",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Zerbitzari-aldeko enkriptazioak zerbitzarira igotzen diren fitxategiak enkriptatzeabaimentzen du. Honek eraginkortasuna jaitsi dezake, beraz gaitu beharrezkoa bada soilik. ",
    "Enable server-side encryption" : "Gaitu zerbitzariaren aldeko enkriptaketa",
    "Please read carefully before activating server-side encryption: " : "Mesedez, irakurri arretaz zerbitzariaren aldeko enkriptaketa gaitu aurretik:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases.",
    "Be aware that encryption always increases the file size." : "Be aware that encryption always increases the file size.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data.",
    "This is the final warning: Do you really want to enable encryption?" : "This is the final warning: Do you really want to enable encryption?",
    "Enable encryption" : "Gaitu enkriptatzea",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ez da enkriptazio modulurik kargatu, mesedez enkriptazio modulu bat gaitu app-en menuan. ",
    "Select default encryption module:" : "Defektuzko enkriptazio modulua hautatu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Enkriptazio gakoak enkriptazio sistema zaharretik (ownCloud <=8.0) sistema berrira migratu behar duzu. Gaitu mesedez \" Defektuzko enkriptazio modulua\" eta 'occ encryption:migrate' exekuta ezazu",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Enkriptazio gakoak sistema zaharretik (ownCloud <=8.0) berrira migratu behar duzu",
    "Start migration" : "Migrazioa hasi",
    "Background jobs" : "Atzeko planoko lanak",
    "Last job ran %s." : "Azken lana %s itzuli zuen. ",
    "Last job execution ran %s. Something seems wrong." : "Azken lanaren exekuzioak %s itzuli zuen. Zerbait gaizki joan da ",
    "Background job didn’t run yet!" : "Atzeko planoko lana ez da martxan jarri oraindik!",
    "Execute one task with each page loaded" : "Exekutatu zeregin bat orri karga bakoitzean",
    "The cron.php needs to be executed by the system user \"%s\"." : "Sistemako \"%s\" erabiltzaileak, cron.php exekutatu behar du.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Hau exekutatzeko PHP POSIX luzapena behar duzu. {linkstart}PHP dokumentazioa{linkend} ikusi informazio gehiagorako",
    "Sharing" : "Partekatzea",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Admin bezala partekatze portaerak zehazki konfigura daitezke. Dokumentazioaikusi informazio gehiagorako. ",
    "Allow apps to use the Share API" : "Baimendu aplikazioak partekatzeko APIa erabiltzeko",
    "Allow users to share via link" : "Baimendu erabiltzaileak esteken bidez partekatzea",
    "Allow public uploads" : "Baimendu igoera publikoak",
    "Always ask for a password" : "Beti eskatu pasahitza",
    "Enforce password protection" : "Betearazi pasahitzaren babesa",
    "Set default expiration date" : "Ezarri iraungitze-data lehenetsia",
    "Expire after " : "Iraungia honen ondoren",
    "days" : "egun",
    "Enforce expiration date" : "Betearazi iraungitze-data",
    "Allow resharing" : "Baimendu birpartekatzea",
    "Allow sharing with groups" : "Onartu taldeekin partekatzen",
    "Restrict users to only share with users in their groups" : "Mugatu partekatzeak taldeko erabiltzaileetara",
    "Exclude groups from sharing" : "Baztertu taldeak partekatzean",
    "These groups will still be able to receive shares, but not to initiate them." : "Talde hauek oraindik jaso ahal izango dute partekatzeak, baina ezingo dute partekatu",
    "Personal" : "Pertsonala",
    "Administration" : "Administrazioa",
    "Like our Facebook page" : "Gure Facebook orrian Like egin",
    "Follow us on Twitter" : "Jarrai gaitzazu Twitterren",
    "Follow us on Mastodon" : "Jarraitu gaitzazu Mastodon-en",
    "Check out our blog" : "Gure bloga kontsultatu",
    "Subscribe to our newsletter" : "Izena eman gure buletinean",
    "Profile picture" : "Zure irudia",
    "Upload new" : "Igo berria",
    "Select from Files" : "Aukeratu fitxategien artean",
    "Remove image" : "Kendu irudia",
    "png or jpg, max. 20 MB" : "png edo jpg, gehienez 20MB",
    "Picture provided by original account" : "Irudia jatorrizko kontutik hartuta",
    "Cancel" : "Ezeztatu",
    "Choose as profile picture" : "Aukeratu profil irudi gisa",
    "Details" : "Xehetasunak",
    "Full name" : "Izen osoa",
    "No display name set" : "Ez da bistaratze izena ezarri",
    "Your email address" : "Zure e-posta",
    "No email address set" : "Ez da eposta helbidea ezarri",
    "For password reset and notifications" : "Pasahitza berrezartzeko eta jakinarazpenerako",
    "Phone number" : "Telefono zenbakia",
    "Your phone number" : "Zure telefono zenbakia",
    "Address" : "Helbidea",
    "Your postal address" : "Zure helbidea",
    "Website" : "Webgunea",
    "It can take up to 24 hours before the account is displayed as verified." : "24 ordu pasa daitezke kontua ziurtatua bezala agertu baino lehen",
    "Link https://…" : "https://... esteka",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter heldulekua @...",
    "Help translate" : "Lagundu itzultzen",
    "Current password" : "Uneko pasahitza",
    "Change password" : "Aldatu pasahitza",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "Serbian" : "Serbiera",
    "Sinhala (Sri Lanka)" : "Sinhala (Sri Lanka)",
    "Sinhala" : "Sinhala",
    "Slovak (Slovakia)" : "Eslovakiera (Eslovakia)",
    "Slovak" : "Eslovakiera",
    "Slovenian (Slovenia)" : "Esloveniera (Eslovenia)",
    "Slovenian" : "Esloveniera",
    "Somali (Ethiopia)" : "Somaliera (Etiopia)",
    "Somali (Kenya)" : "Somaliera (Kenya)",
    "Somali (Somalia)" : "Somaliera (Somalia)",
    "Somali" : "Somaliera",
    "Spanish (Argentina)" : "Gaztelania (Argentina)",
    "Spanish (Bolivia)" : "Gaztelania (Bolivia)",
    "Spanish (Chile)" : "Gaztelania (Txile)",
    "Spanish (Colombia)" : "Gaztelania (Kolombia)",
    "Spanish (Costa Rica)" : "Gaztelania (Costa Rica)",
    "Spanish (Dominican Republic)" : "Gaztelania (Dominikar Errepublika)",
    "Spanish (Ecuador)" : "Gaztelania (Ecuador)",
    "Spanish (El Salvador)" : "Gaztelania (El Salvador)",
    "Spanish (Equatorial Guinea)" : "Gaztelania (Ekuatore Ginea)",
    "Spanish (Guatemala)" : "Gaztelania (Guatemala)",
    "Spanish (Honduras)" : "Gaztelania (Honduras)",
    "Spanish (Latin America)" : "Gaztelania (Latinoamerika)",
    "Spanish (Mexico)" : "Gaztelania (Mexico)",
    "Spanish (Nicaragua)" : "Gaztelania (Nicaragua)",
    "Spanish (Panama)" : "Gaztelania (Panama)",
    "Spanish (Paraguay)" : "Gaztelania (Paraguay)",
    "Spanish (Peru)" : "Gaztelania (Peru)",
    "Spanish (Puerto Rico)" : "Gaztelania (Puerto Rico)",
    "Spanish (Spain)" : "Gaztelania (Espainia)",
    "Spanish (United States)" : "Gaztelania (Estatu Batuak)",
    "Spanish (Uruguay)" : "Gaztelania (Uruguay)",
    "Spanish (Venezuela)" : "Gaztelania (Venezuela)",
    "Spanish" : "Gaztelania",
    "Swahili (Kenya)" : "Swahili (Kenya)",
    "Swahili (Tanzania)" : "Swahili (Tanzania)",
    "Swahili" : "Swahili",
    "Swedish (Finland)" : "Suediera (Finlandia)",
    "Swedish (Sweden)" : "Suediera (Suedia)",
    "Swedish" : "Suediera",
    "Tamil (India)" : "Tamilera (India)",
    "Tamil (Sri Lanka)" : "Tamilera (Sri Lanka)",
    "Tamil" : "Tamilera",
    "Telugu (India)" : "Telugu (India)",
    "Telugu" : "Telugu",
    "Teso (Kenya)" : "Teso (Kenya)",
    "Teso (Uganda)" : "Teso (Uganda)",
    "Thai (Thailand)" : "Thaiera (Thailandia)",
    "Thai" : "Thaiera",
    "Tibetan (China)" : "Tibetera (Txina)",
    "Tibetan (India)" : "Tibetera (India)",
    "Tibetan" : "Tibetera",
    "Tonga (Tonga)" : "Tongera (Tonga)",
    "Tonga" : "Tongera",
    "Turkish (Turkey)" : "Turkiera (Turkia)",
    "Turkish" : "Turkiera",
    "Ukrainian (Ukraine)" : "Ukrainera (Ukrania)",
    "Ukrainian" : "Ukrainera",
    "Urdu (India)" : "Urdu (India)",
    "Urdu (Pakistan)" : "Urdu (Pakistan)",
    "Urdu" : "Urdu",
    "Uzbek (Arabic)" : "Uzbekera (Arabiarra)",
    "Uzbek (Arabic, Afghanistan)" : "Uzbekera (Arabiarra, Afghanistan)",
    "Uzbek" : "Uzbekera",
    "Vietnamese (Vietnam)" : "Vietnamera (Vietnam)",
    "Vietnamese" : "Vietnamera",
    "Welsh (United Kingdom)" : "Gales (Erresuma Batua)",
    "Welsh" : "Gales",
    "Yoruba (Nigeria)" : "Jorubera (Nigeria)",
    "Yoruba" : "Jorubera",
    "Zulu (South Africa)" : "Zuluera (Hego Afrika)",
    "Zulu" : "Zuluera",
    "Store credentials" : "Gorde kredentzialak",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php webcrom zerbitzu bezala erregistratua dago, cron.php 15 minuturo HTTP bidez deitu ahal izateko.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Sistemaren cron zerbitzua erabili cron.php 15 minuturo deitzeko."
},
"nplurals=2; plural=(n != 1);");
